import { Injectable } from '@angular/core';
import { Recipe } from '../models/recipe';
import { IngredientRecipe } from '../models/ingredient-recipe';

@Injectable({
  providedIn: 'root',
})
export class RecipeService {
  private localStorageKey = 'recipes';
  private ingredientRecipeKey = 'ingredientRecipes';

  getRecipes(): Recipe[] {
    const recipesJson = localStorage.getItem(this.localStorageKey);
    return recipesJson ? JSON.parse(recipesJson) : [];
  }

  addRecipe(recipe: Recipe): void {
    const recipes = this.getRecipes();
    recipes.push(recipe);
    localStorage.setItem(this.localStorageKey, JSON.stringify(recipes));
  }

  deleteRecipe(recipeId: number): void {
    let recipes = this.getRecipes();
    recipes = recipes.filter(recipe => recipe.id !== recipeId);
    localStorage.setItem(this.localStorageKey, JSON.stringify(recipes));
  }

  getIngredientRecipes(recipeId: number): IngredientRecipe[] {
    const ingredientRecipes: IngredientRecipe[] = JSON.parse(
      localStorage.getItem(this.ingredientRecipeKey) || '[]'
    );
    return ingredientRecipes.filter((ir) => ir.idRecipe === recipeId);
  }

  addIngredientRecipe(ingredientRecipe: IngredientRecipe): void {
    const ingredientRecipes = this.getIngredientRecipes(ingredientRecipe.idRecipe);
    ingredientRecipes.push(ingredientRecipe);
    localStorage.setItem(this.ingredientRecipeKey, JSON.stringify(ingredientRecipes));
  }

  getIngredientQuantity(ingredientId: number, ingredientRecipes: IngredientRecipe[]): number {
    const ingredientRecipe = ingredientRecipes.find(
      (ir) => ir.idIngredient === ingredientId
    );
    return ingredientRecipe ? ingredientRecipe.quantity : 0;
  }
}
